@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/dialogs/qcolordialog.cpp   2.2.0   edited 2000-08-25 $
+** $Id: qt/src/dialogs/qcolordialog.cpp   2.2.1   edited 2000-09-25 $
 **
 ** Implementation of QColorDialog class
 **
@@ -1253,8 +1253,6 @@ void QColorShower::hsvEd()
 void QColorShower::setRgb( QRgb rgb )
 {
     rgbOriginal = TRUE;
-    if ( currentColor() == rgb )
-	return;
     curCol = rgb;
 
     rgb2hsv( currentColor(), hue, sat, val );
@@ -1273,8 +1271,6 @@ void QColorShower::setRgb( QRgb rgb )
 void QColorShower::setHsv( int h, int s, int v )
 {
     rgbOriginal = FALSE;
-    if ( h == hue && v == val && s == sat )
-	return;
     hue = h; val = v; sat = s; //Range check###
     curCol = QColor( hue, sat, val, QColor::Hsv ).rgb();
 
