@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/kernel/qabstractlayout.cpp   2.2.0   edited 2000-08-25 $
+** $Id: qt/src/kernel/qabstractlayout.cpp   2.2.1   edited 2000-09-18 $
 **
 ** Implementation of the abstract layout base class
 **
@@ -324,8 +324,9 @@ int QLayoutItem::heightForWidth( int ) const
 static const int HorAlign = Qt::AlignHCenter | Qt::AlignRight | Qt::AlignLeft;
 static const int VerAlign = Qt::AlignVCenter | Qt::AlignBottom | Qt::AlignTop;
 
-static QSize smartMinSize( QWidget *w )
+static QSize smartMinSize( const QWidgetItem *i )
 {
+    QWidget *w = ( (QWidgetItem*)i )->widget();
     QSize s(0,0);
     if ( w->layout() ) {
 	s = w->layout()->totalMinimumSize();
@@ -346,6 +347,9 @@ static QSize smartMinSize( QWidget *w )
     if ( min.height() > 0 )
 	s.setHeight( min.height() );
 
+    if ( i->hasHeightForWidth() && min.height() == 0 && min.width() > 0 )
+	s.setHeight( i->heightForWidth( s.width() ) );
+    
     s = s.expandedTo( QSize(1,1) );
     return s;
 }
@@ -520,7 +524,7 @@ QSize QWidgetItem::minimumSize() const
 {
     if ( isEmpty() )
 	return QSize(0,0);
-    return smartMinSize( wid );
+    return smartMinSize( this );
 }
 
 
