@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/kernel/qfont.cpp   2.2.0   edited 2000-08-25 $
+** $Id: qt/src/kernel/qfont.cpp   2.2.1   edited 2000-09-02 $
 **
 ** Implementation of QFont, QFontMetrics and QFontInfo classes
 **
@@ -197,7 +197,9 @@
   <li> \c QFont::ISO_8859_10..15, other ISO 8859 characters sets
   <li> \c QFont::KOI8R - KOI8-R, Cyrillic, defined in
        <a href="ftp://ftp.nordu.net/rfc/rfc1489.txt">RFC 1489.</a>
-  <li> \c QFont::AnyCharSet - whatever is handiest.
+   <li> \c QFont::KOI8U - KOI8-U, Cyrillic/Ukrainian, defined in
+       <a href="ftp://ftp.nordu.net/rfc/rfc2319.txt">RFC 2319.</a>
+   <li> \c QFont::AnyCharSet - whatever is handiest.
   <li> \c QFont::Set_Ja, Japanese
   <li> \c QFont::Set_Ko, Korean
   <li> \c QFont::Set_Th_TH
@@ -1016,6 +1018,9 @@ QString QFont::encodingName( CharSet cs )
     case QFont::KOI8R:
         result = "KOI8-R";
         break;
+    case QFont::KOI8U:
+        result = "KOI8-U";
+        break;
     case QFont::Set_Ja:
         result = "Set_Ja";
         break;
