@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/network/qdns.cpp   2.2.0   edited 2000-08-26 $
+** $Id: qt/src/network/qdns.cpp   2.2.1   edited 2000-09-10 $
 **
 ** Implementation of QDns class.
 **
@@ -1953,11 +1953,11 @@ QString QDns::canonicalName() const
 
 #include <sys/types.h>
 #include <netinet/in.h>
-#if defined (_OS_SCO_) // SCO OpenServer 5.0.5
+#if defined (_OS_SCO_) || defined (_OS_AIX_)
 # define class c_class
 #endif
 #include <arpa/nameser.h>
-#if defined (_OS_SCO_)
+#if defined (_OS_SCO_) || defined (_OS_AIX_)
 # undef class
 #endif
 #include <resolv.h>
@@ -2009,11 +2009,11 @@ static void doResInit()
 	while( !i.atEnd() ) {
 	    line = i.readLine().simplifyWhiteSpace().lower();
 	    uint n = 0;
-	    while( n < line.length() && line[n] != '#' )
+	    while( n < line.length() && line[(int)n] != '#' )
 		n++;
 	    line.truncate( n );
 	    n = 0;
-	    while( n < line.length() && !line[n].isSpace() )
+	    while( n < line.length() && !line[(int)n].isSpace() )
 		n++;
 	    QString ip = line.left( n );
 	    QHostAddress a;
@@ -2022,7 +2022,7 @@ static void doResInit()
 		bool first = TRUE;
 		line = line.mid( n+1 );
 		n = 0;
-		while( n < line.length() && !line[n].isSpace() )
+		while( n < line.length() && !line[(int)n].isSpace() )
 		    n++;
 		QString hostname = line.left( n );
 		// ### in case of bad syntax, hostname is invalid. do we care?
@@ -2129,7 +2129,7 @@ static void doResInit()
     if ( QApplication::winVersion() == Qt::WV_98 ||
 	 QApplication::winVersion() == Qt::WV_2000 ) {
 	// for 98 and 2000 try the API call GetNetworkParams()
-	HINSTANCE hinstLib = LoadLibraryA( "iphlpapi" );
+	HINSTANCE hinstLib = LoadLibraryA( "iphlpapi" ); // we don't need Unicode here
 	if ( hinstLib != 0 ) {
 	    GNP getNetworkParams = (GNP) GetProcAddress( hinstLib, "GetNetworkParams" );
 	    if ( getNetworkParams != 0 ) {
