@@ -1,5 +1,5 @@
 /**********************************************************************
-** $Id: qt/src/widgets/qlistbox.cpp   2.2.0   edited 2000-08-25 $
+** $Id: qt/src/widgets/qlistbox.cpp   2.2.1   edited 2000-10-01 $
 **
 ** Implementation of QListBox widget class
 **
@@ -1164,6 +1164,9 @@ void QListBox::insertItem( const QListBoxItem *lbi, int index )
     if ( hasFocus() && !d->current ) {
 	d->current = d->head;
 	updateItem( d->current );
+	emit highlighted( d->current );
+	emit highlighted( d->current->text() );
+	emit highlighted( index );
     }
 
     triggerUpdate( TRUE );
@@ -1213,10 +1216,12 @@ void QListBox::insertItem( const QListBoxItem *lbi, const QListBoxItem *after )
     if ( after == d->last )
 	d->last = (QListBoxItem*) lbi;
 
-
     if ( hasFocus() && !d->current ) {
 	d->current = d->head;
 	updateItem( d->current );
+	emit highlighted( d->current );
+	emit highlighted( d->current->text() );
+	emit highlighted( index( d->current ) );
     }
 
     triggerUpdate( TRUE );
@@ -1308,6 +1313,7 @@ void QListBox::clear()
     clearSelection();
     blockSignals( FALSE );
     triggerUpdate( TRUE );
+    d->last = 0;
     d->clearing = FALSE;
 }
 
